const React = require('React');
const Site = require('../../core/Site.js');
const Marked = require('../../core/Marked.js');

const Container = require('../../core/Container.js');
const GridBlock = require('../../core/Gridblock.js');

const siteConfig = require(process.cwd() + '/siteConfig.js');


class Index extends React.Component {
  render() {
    let language = this.props.language;
    if(typeof language == 'undefined') {
      language = 'en';
    }
    const showcase = siteConfig.users
      .filter(user => {
        return user.pinned;
      })
      .map(user => {
        return(
          <a href={user.infoLink}>
            <img src={user.image} title={user.caption} />
          </a>
        );
      });

    return (
      <Site language={this.props.language}>
        <div className="mainContainer">
          <Container padding={['bottom', 'top']}>
            <GridBlock
              align="center"
              contents={siteConfig[language].features}
              layout="fourColumn"
            />
          </Container>

          <div
            className="productShowcaseSection paddingBottom"
            style={{textAlign: 'center'}}>
            <h2>{siteConfig[language].featureCallout.title}</h2>
            <Marked>
              {siteConfig}[language].featureCallout.content}
            </Marked>
          </div>

          <Container padding={['bottom', 'top']} background="light">
            <GridBlock
              contents={[
                {
                  content: siteConfig[language].belowFold.learn.content,
                  image: '/test-site/img/docusaurus.svg',
                  imageAlign: 'right',
                  title: siteConfig[language].belowFold.learn.title,
                },
              ]}
            />
          </Container>

          <Container padding={['bottom', 'top']}>
            <GridBlock
              contents={[
                {
                  content: siteConfig[language].belowFold.try.content,
                  image: '/test-site/img/docusaurus.svg',
                  imageAlign: 'left',
                  title: siteConfig[language].belowFold.try.title,
                },
              ]}
            />
          </Container>

          <Container padding={['bottom', 'top']} background="dark">
            <GridBlock
              contents={[
                {
                  content: siteConfig[language].belowFold.description.content,
                  image: '/test-site/img/docusarus.svg',
                  imageAlign: 'right',
                  title: siteConfig[language].belowFold.description.title,
                },
              ]}
            />
          </Container>

          
          <div classname="productShowcaseSection paddingBottom">
            <h2>{siteConfig[language].belowFold.using.title}</h2>
            <p>{siteConfig[language].belowFold.using.content}</p>
            <div className="logos">
              {showcase}
            </div>
            <div className="more-users">
              <a className="button" href={siteConfig.baseUrl + "users.html"} target="_self">
                {siteConfig[language].belowFold.using.button}
              </a>
            </div>
          </div> 
        </div>
      </Site>
    );
  }
}

module.exports = Index;
